# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import peer_pb2 as peer__pb2
import block_pb2 as block__pb2
import transaction_pb2 as transaction__pb2
import utxo_pb2 as utxo__pb2
import datastore_pb2 as datastore__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpc.proto',
  package='rpcpb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\trpc.proto\x12\x05rpcpb\x1a\npeer.proto\x1a\x0b\x62lock.proto\x1a\x11transaction.proto\x1a\nutxo.proto\x1a\x0f\x64\x61tastore.proto\"*\n\x14\x43reateAccountRequest\x12\x12\n\npassphrase\x18\x01 \x01(\t\"\x16\n\x14UnlockAccountRequest\"%\n\x12\x41\x64\x64ProducerRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"$\n\x11GetBalanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"2\n\x14SendFromMinerRequest\x12\n\n\x02to\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x0c\"\x8e\x01\n\x0bSendRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63ount_path\x18\x04 \x01(\t\x12\x0b\n\x03tip\x18\x05 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\x12\x11\n\tgas_limit\x18\x07 \x01(\x0c\x12\x11\n\tgas_price\x18\x08 \x01(\x0c\"\x14\n\x12GetPeerInfoRequest\"\x1a\n\x18GetBlockchainInfoRequest\"&\n\x0e\x41\x64\x64PeerRequest\x12\x14\n\x0c\x66ull_address\x18\x01 \x01(\t\"*\n\x11GetVersionRequest\x12\x15\n\rproto_version\x18\x01 \x01(\t\"!\n\x0eGetUTXORequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"A\n\x10GetBlocksRequest\x12\x1a\n\x12start_block_hashes\x18\x01 \x03(\x0c\x12\x11\n\tmax_count\x18\x02 \x01(\x05\"%\n\x15GetBlockByHashRequest\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\")\n\x17GetBlockByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"I\n\x16SendTransactionRequest\x12/\n\x0btransaction\x18\x01 \x01(\x0b\x32\x1a.transactionpb.Transaction\"O\n\x1bSendBatchTransactionRequest\x12\x30\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x1a.transactionpb.Transaction\"\x1a\n\x18GetNewTransactionRequest\"\"\n\x10SubscribeRequest\x12\x0e\n\x06topics\x18\x01 \x03(\t\"\x17\n\x15MetricsServiceRequest\"!\n\x1fGetLastIrreversibleBlockRequest\"E\n\x12\x45stimateGasRequest\x12/\n\x0btransaction\x18\x01 \x01(\x0b\x32\x1a.transactionpb.Transaction\"\x11\n\x0fGasPriceRequest\"I\n\x14\x43ontractQueryRequest\x12\x15\n\rcontract_addr\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x15\n\x13\x41\x64\x64ProducerResponse\"\x17\n\x15UnlockAccountResponse\"$\n\x12GetBalanceResponse\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x03\"\x17\n\x15SendFromMinerResponse\"6\n\x0cSendResponse\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x0c\n\x04txid\x18\x02 \x01(\t\"=\n\x13GetPeerInfoResponse\x12&\n\tpeer_list\x18\x01 \x03(\x0b\x32\x13.networkpb.PeerInfo\"p\n\x19GetBlockchainInfoResponse\x12\x17\n\x0ftail_block_hash\x18\x01 \x01(\x0c\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x11\n\tproducers\x18\x03 \x03(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\"\x11\n\x0f\x41\x64\x64PeerResponse\"C\n\x12GetVersionResponse\x12\x15\n\rproto_version\x18\x01 \x01(\t\x12\x16\n\x0eserver_version\x18\x02 \x01(\t\"[\n\x0fGetUTXOResponse\x12\x1b\n\x05utxos\x18\x01 \x03(\x0b\x32\x0c.utxopb.Utxo\x12+\n\rblock_headers\x18\x02 \x03(\x0b\x32\x14.blockpb.BlockHeader\"3\n\x11GetBlocksResponse\x12\x1e\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x0e.blockpb.Block\"7\n\x16GetBlockByHashResponse\x12\x1d\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x0e.blockpb.Block\"9\n\x18GetBlockByHeightResponse\x12\x1d\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x0e.blockpb.Block\"=\n\x17SendTransactionResponse\x12\"\n\x1agenerated_contract_address\x18\x01 \x01(\t\"\x1e\n\x1cSendBatchTransactionResponse\"D\n\x15SendTransactionStatus\x12\x0c\n\x04txid\x18\x01 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\"L\n\x19GetNewTransactionResponse\x12/\n\x0btransaction\x18\x01 \x01(\x0b\x32\x1a.transactionpb.Transaction\"!\n\x11SubscribeResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x1b\n\x19GetAllTransactionsRequest\"N\n\x1aGetAllTransactionsResponse\x12\x30\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x1a.transactionpb.Transaction\"A\n GetLastIrreversibleBlockResponse\x12\x1d\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x0e.blockpb.Block\"5\n\x10GetStatsResponse\x12!\n\x05stats\x18\x01 \x01(\x0b\x32\x12.metricspb.Metrics\"\xeb\x01\n\x15GetNodeConfigResponse\x12\x15\n\rtx_pool_limit\x18\x01 \x01(\r\x12\x16\n\x0e\x62lk_size_limit\x18\x02 \x01(\r\x12\x1a\n\x12max_connection_out\x18\x03 \x01(\r\x12\x19\n\x11max_connection_in\x18\x04 \x01(\r\x12\x18\n\x10producer_address\x18\x05 \x01(\t\x12\x11\n\tproducers\x18\x06 \x03(\t\x12\x15\n\rmax_producers\x18\x07 \x01(\r\x12\x16\n\x0eipfs_addresses\x18\t \x03(\t\x12\x10\n\x08rpc_port\x18\n \x01(\r\"\xe1\x02\n\x14SetNodeConfigRequest\x12?\n\x0fupdated_configs\x18\x01 \x03(\x0e\x32&.rpcpb.SetNodeConfigRequest.ConfigType\x12\x15\n\rtx_pool_limit\x18\x02 \x01(\r\x12\x16\n\x0e\x62lk_size_limit\x18\x03 \x01(\r\x12\x1a\n\x12max_connection_out\x18\x04 \x01(\r\x12\x19\n\x11max_connection_in\x18\x05 \x01(\r\x12\x15\n\rmax_producers\x18\x06 \x01(\r\x12\x11\n\tproducers\x18\x07 \x03(\t\"x\n\nConfigType\x12\x11\n\rTX_POOL_LIMIT\x10\x00\x12\x12\n\x0e\x42LK_SIZE_LIMIT\x10\x01\x12\x10\n\x0cMAX_CONN_OUT\x10\x02\x12\x0f\n\x0bMAX_CONN_IN\x10\x03\x12\x11\n\rMAX_PRODUCERS\x10\x04\x12\r\n\tPRODUCERS\x10\x05\"(\n\x13\x45stimateGasResponse\x12\x11\n\tgas_count\x18\x01 \x01(\x0c\"%\n\x10GasPriceResponse\x12\x11\n\tgas_price\x18\x01 \x01(\x0c\"3\n\x15\x43ontractQueryResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2\xc8\n\n\nRpcService\x12\x46\n\rRpcGetVersion\x12\x18.rpcpb.GetVersionRequest\x1a\x19.rpcpb.GetVersionResponse\"\x00\x12\x46\n\rRpcGetBalance\x12\x18.rpcpb.GetBalanceRequest\x1a\x19.rpcpb.GetBalanceResponse\"\x00\x12[\n\x14RpcGetBlockchainInfo\x12\x1f.rpcpb.GetBlockchainInfoRequest\x1a .rpcpb.GetBlockchainInfoResponse\"\x00\x12=\n\nRpcGetUTXO\x12\x15.rpcpb.GetUTXORequest\x1a\x16.rpcpb.GetUTXOResponse\"\x00\x12\x43\n\x0cRpcGetBlocks\x12\x17.rpcpb.GetBlocksRequest\x1a\x18.rpcpb.GetBlocksResponse\"\x00\x12R\n\x11RpcGetBlockByHash\x12\x1c.rpcpb.GetBlockByHashRequest\x1a\x1d.rpcpb.GetBlockByHashResponse\"\x00\x12X\n\x13RpcGetBlockByHeight\x12\x1e.rpcpb.GetBlockByHeightRequest\x1a\x1f.rpcpb.GetBlockByHeightResponse\"\x00\x12U\n\x12RpcSendTransaction\x12\x1d.rpcpb.SendTransactionRequest\x1a\x1e.rpcpb.SendTransactionResponse\"\x00\x12\x64\n\x17RpcSendBatchTransaction\x12\".rpcpb.SendBatchTransactionRequest\x1a#.rpcpb.SendBatchTransactionResponse\"\x00\x12]\n\x14RpcGetNewTransaction\x12\x1f.rpcpb.GetNewTransactionRequest\x1a .rpcpb.GetNewTransactionResponse\"\x00\x30\x01\x12\x45\n\x0cRpcSubscribe\x12\x17.rpcpb.SubscribeRequest\x1a\x18.rpcpb.SubscribeResponse\"\x00\x30\x01\x12h\n\x1fRpcGetAllTransactionsFromTxPool\x12 .rpcpb.GetAllTransactionsRequest\x1a!.rpcpb.GetAllTransactionsResponse\"\x00\x12p\n\x1bRpcGetLastIrreversibleBlock\x12&.rpcpb.GetLastIrreversibleBlockRequest\x1a\'.rpcpb.GetLastIrreversibleBlockResponse\"\x00\x12I\n\x0eRpcEstimateGas\x12\x19.rpcpb.EstimateGasRequest\x1a\x1a.rpcpb.EstimateGasResponse\"\x00\x12@\n\x0bRpcGasPrice\x12\x16.rpcpb.GasPriceRequest\x1a\x17.rpcpb.GasPriceResponse\"\x00\x12O\n\x10RpcContractQuery\x12\x1b.rpcpb.ContractQueryRequest\x1a\x1c.rpcpb.ContractQueryResponse\"\x00\x32\xbb\x03\n\x0c\x41\x64minService\x12=\n\nRpcAddPeer\x12\x15.rpcpb.AddPeerRequest\x1a\x16.rpcpb.AddPeerResponse\"\x00\x12\x34\n\x07RpcSend\x12\x12.rpcpb.SendRequest\x1a\x13.rpcpb.SendResponse\"\x00\x12I\n\x0eRpcGetPeerInfo\x12\x19.rpcpb.GetPeerInfoRequest\x1a\x1a.rpcpb.GetPeerInfoResponse\"\x00\x12O\n\x10RpcSendFromMiner\x12\x1b.rpcpb.SendFromMinerRequest\x1a\x1c.rpcpb.SendFromMinerResponse\"\x00\x12I\n\x0eRpcAddProducer\x12\x19.rpcpb.AddProducerRequest\x1a\x1a.rpcpb.AddProducerResponse\"\x00\x12O\n\x10RpcUnlockAccount\x12\x1b.rpcpb.UnlockAccountRequest\x1a\x1c.rpcpb.UnlockAccountResponse\"\x00\x32\xfa\x01\n\rMetricService\x12\x46\n\x0bRpcGetStats\x12\x1c.rpcpb.MetricsServiceRequest\x1a\x17.rpcpb.GetStatsResponse\"\x00\x12P\n\x10RpcGetNodeConfig\x12\x1c.rpcpb.MetricsServiceRequest\x1a\x1c.rpcpb.GetNodeConfigResponse\"\x00\x12O\n\x10RpcSetNodeConfig\x12\x1b.rpcpb.SetNodeConfigRequest\x1a\x1c.rpcpb.GetNodeConfigResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[peer__pb2.DESCRIPTOR,block__pb2.DESCRIPTOR,transaction__pb2.DESCRIPTOR,utxo__pb2.DESCRIPTOR,datastore__pb2.DESCRIPTOR,])



_SETNODECONFIGREQUEST_CONFIGTYPE = _descriptor.EnumDescriptor(
  name='ConfigType',
  full_name='rpcpb.SetNodeConfigRequest.ConfigType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TX_POOL_LIMIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLK_SIZE_LIMIT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX_CONN_OUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX_CONN_IN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX_PRODUCERS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCERS', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2873,
  serialized_end=2993,
)
_sym_db.RegisterEnumDescriptor(_SETNODECONFIGREQUEST_CONFIGTYPE)


_CREATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreateAccountRequest',
  full_name='rpcpb.CreateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='passphrase', full_name='rpcpb.CreateAccountRequest.passphrase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=135,
)


_UNLOCKACCOUNTREQUEST = _descriptor.Descriptor(
  name='UnlockAccountRequest',
  full_name='rpcpb.UnlockAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=159,
)


_ADDPRODUCERREQUEST = _descriptor.Descriptor(
  name='AddProducerRequest',
  full_name='rpcpb.AddProducerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='rpcpb.AddProducerRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=198,
)


_GETBALANCEREQUEST = _descriptor.Descriptor(
  name='GetBalanceRequest',
  full_name='rpcpb.GetBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='rpcpb.GetBalanceRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=236,
)


_SENDFROMMINERREQUEST = _descriptor.Descriptor(
  name='SendFromMinerRequest',
  full_name='rpcpb.SendFromMinerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='to', full_name='rpcpb.SendFromMinerRequest.to', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='rpcpb.SendFromMinerRequest.amount', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=288,
)


_SENDREQUEST = _descriptor.Descriptor(
  name='SendRequest',
  full_name='rpcpb.SendRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='rpcpb.SendRequest.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='rpcpb.SendRequest.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='rpcpb.SendRequest.amount', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_path', full_name='rpcpb.SendRequest.account_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tip', full_name='rpcpb.SendRequest.tip', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='rpcpb.SendRequest.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gas_limit', full_name='rpcpb.SendRequest.gas_limit', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gas_price', full_name='rpcpb.SendRequest.gas_price', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=433,
)


_GETPEERINFOREQUEST = _descriptor.Descriptor(
  name='GetPeerInfoRequest',
  full_name='rpcpb.GetPeerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=455,
)


_GETBLOCKCHAININFOREQUEST = _descriptor.Descriptor(
  name='GetBlockchainInfoRequest',
  full_name='rpcpb.GetBlockchainInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=483,
)


_ADDPEERREQUEST = _descriptor.Descriptor(
  name='AddPeerRequest',
  full_name='rpcpb.AddPeerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='full_address', full_name='rpcpb.AddPeerRequest.full_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=523,
)


_GETVERSIONREQUEST = _descriptor.Descriptor(
  name='GetVersionRequest',
  full_name='rpcpb.GetVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proto_version', full_name='rpcpb.GetVersionRequest.proto_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=567,
)


_GETUTXOREQUEST = _descriptor.Descriptor(
  name='GetUTXORequest',
  full_name='rpcpb.GetUTXORequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='rpcpb.GetUTXORequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=602,
)


_GETBLOCKSREQUEST = _descriptor.Descriptor(
  name='GetBlocksRequest',
  full_name='rpcpb.GetBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_block_hashes', full_name='rpcpb.GetBlocksRequest.start_block_hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_count', full_name='rpcpb.GetBlocksRequest.max_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=669,
)


_GETBLOCKBYHASHREQUEST = _descriptor.Descriptor(
  name='GetBlockByHashRequest',
  full_name='rpcpb.GetBlockByHashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='rpcpb.GetBlockByHashRequest.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=671,
  serialized_end=708,
)


_GETBLOCKBYHEIGHTREQUEST = _descriptor.Descriptor(
  name='GetBlockByHeightRequest',
  full_name='rpcpb.GetBlockByHeightRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='rpcpb.GetBlockByHeightRequest.height', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=751,
)


_SENDTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SendTransactionRequest',
  full_name='rpcpb.SendTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='rpcpb.SendTransactionRequest.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=826,
)


_SENDBATCHTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SendBatchTransactionRequest',
  full_name='rpcpb.SendBatchTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='rpcpb.SendBatchTransactionRequest.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=907,
)


_GETNEWTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='GetNewTransactionRequest',
  full_name='rpcpb.GetNewTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=935,
)


_SUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='SubscribeRequest',
  full_name='rpcpb.SubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topics', full_name='rpcpb.SubscribeRequest.topics', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=971,
)


_METRICSSERVICEREQUEST = _descriptor.Descriptor(
  name='MetricsServiceRequest',
  full_name='rpcpb.MetricsServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=996,
)


_GETLASTIRREVERSIBLEBLOCKREQUEST = _descriptor.Descriptor(
  name='GetLastIrreversibleBlockRequest',
  full_name='rpcpb.GetLastIrreversibleBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1031,
)


_ESTIMATEGASREQUEST = _descriptor.Descriptor(
  name='EstimateGasRequest',
  full_name='rpcpb.EstimateGasRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='rpcpb.EstimateGasRequest.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1033,
  serialized_end=1102,
)


_GASPRICEREQUEST = _descriptor.Descriptor(
  name='GasPriceRequest',
  full_name='rpcpb.GasPriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1121,
)


_CONTRACTQUERYREQUEST = _descriptor.Descriptor(
  name='ContractQueryRequest',
  full_name='rpcpb.ContractQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract_addr', full_name='rpcpb.ContractQueryRequest.contract_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='rpcpb.ContractQueryRequest.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='rpcpb.ContractQueryRequest.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1196,
)


_ADDPRODUCERRESPONSE = _descriptor.Descriptor(
  name='AddProducerResponse',
  full_name='rpcpb.AddProducerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1219,
)


_UNLOCKACCOUNTRESPONSE = _descriptor.Descriptor(
  name='UnlockAccountResponse',
  full_name='rpcpb.UnlockAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1221,
  serialized_end=1244,
)


_GETBALANCERESPONSE = _descriptor.Descriptor(
  name='GetBalanceResponse',
  full_name='rpcpb.GetBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='rpcpb.GetBalanceResponse.amount', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1246,
  serialized_end=1282,
)


_SENDFROMMINERRESPONSE = _descriptor.Descriptor(
  name='SendFromMinerResponse',
  full_name='rpcpb.SendFromMinerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1307,
)


_SENDRESPONSE = _descriptor.Descriptor(
  name='SendResponse',
  full_name='rpcpb.SendResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract_address', full_name='rpcpb.SendResponse.contract_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txid', full_name='rpcpb.SendResponse.txid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1363,
)


_GETPEERINFORESPONSE = _descriptor.Descriptor(
  name='GetPeerInfoResponse',
  full_name='rpcpb.GetPeerInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_list', full_name='rpcpb.GetPeerInfoResponse.peer_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1365,
  serialized_end=1426,
)


_GETBLOCKCHAININFORESPONSE = _descriptor.Descriptor(
  name='GetBlockchainInfoResponse',
  full_name='rpcpb.GetBlockchainInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tail_block_hash', full_name='rpcpb.GetBlockchainInfoResponse.tail_block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='rpcpb.GetBlockchainInfoResponse.block_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producers', full_name='rpcpb.GetBlockchainInfoResponse.producers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rpcpb.GetBlockchainInfoResponse.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1428,
  serialized_end=1540,
)


_ADDPEERRESPONSE = _descriptor.Descriptor(
  name='AddPeerResponse',
  full_name='rpcpb.AddPeerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1542,
  serialized_end=1559,
)


_GETVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetVersionResponse',
  full_name='rpcpb.GetVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proto_version', full_name='rpcpb.GetVersionResponse.proto_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_version', full_name='rpcpb.GetVersionResponse.server_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1561,
  serialized_end=1628,
)


_GETUTXORESPONSE = _descriptor.Descriptor(
  name='GetUTXOResponse',
  full_name='rpcpb.GetUTXOResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='utxos', full_name='rpcpb.GetUTXOResponse.utxos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_headers', full_name='rpcpb.GetUTXOResponse.block_headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1630,
  serialized_end=1721,
)


_GETBLOCKSRESPONSE = _descriptor.Descriptor(
  name='GetBlocksResponse',
  full_name='rpcpb.GetBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='rpcpb.GetBlocksResponse.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1723,
  serialized_end=1774,
)


_GETBLOCKBYHASHRESPONSE = _descriptor.Descriptor(
  name='GetBlockByHashResponse',
  full_name='rpcpb.GetBlockByHashResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='rpcpb.GetBlockByHashResponse.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1776,
  serialized_end=1831,
)


_GETBLOCKBYHEIGHTRESPONSE = _descriptor.Descriptor(
  name='GetBlockByHeightResponse',
  full_name='rpcpb.GetBlockByHeightResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='rpcpb.GetBlockByHeightResponse.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=1890,
)


_SENDTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='SendTransactionResponse',
  full_name='rpcpb.SendTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='generated_contract_address', full_name='rpcpb.SendTransactionResponse.generated_contract_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1892,
  serialized_end=1953,
)


_SENDBATCHTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='SendBatchTransactionResponse',
  full_name='rpcpb.SendBatchTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1955,
  serialized_end=1985,
)


_SENDTRANSACTIONSTATUS = _descriptor.Descriptor(
  name='SendTransactionStatus',
  full_name='rpcpb.SendTransactionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txid', full_name='rpcpb.SendTransactionStatus.txid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='rpcpb.SendTransactionStatus.code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='rpcpb.SendTransactionStatus.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1987,
  serialized_end=2055,
)


_GETNEWTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='GetNewTransactionResponse',
  full_name='rpcpb.GetNewTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='rpcpb.GetNewTransactionResponse.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2057,
  serialized_end=2133,
)


_SUBSCRIBERESPONSE = _descriptor.Descriptor(
  name='SubscribeResponse',
  full_name='rpcpb.SubscribeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rpcpb.SubscribeResponse.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2135,
  serialized_end=2168,
)


_GETALLTRANSACTIONSREQUEST = _descriptor.Descriptor(
  name='GetAllTransactionsRequest',
  full_name='rpcpb.GetAllTransactionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2170,
  serialized_end=2197,
)


_GETALLTRANSACTIONSRESPONSE = _descriptor.Descriptor(
  name='GetAllTransactionsResponse',
  full_name='rpcpb.GetAllTransactionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='rpcpb.GetAllTransactionsResponse.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2199,
  serialized_end=2277,
)


_GETLASTIRREVERSIBLEBLOCKRESPONSE = _descriptor.Descriptor(
  name='GetLastIrreversibleBlockResponse',
  full_name='rpcpb.GetLastIrreversibleBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='rpcpb.GetLastIrreversibleBlockResponse.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2279,
  serialized_end=2344,
)


_GETSTATSRESPONSE = _descriptor.Descriptor(
  name='GetStatsResponse',
  full_name='rpcpb.GetStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='rpcpb.GetStatsResponse.stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2346,
  serialized_end=2399,
)


_GETNODECONFIGRESPONSE = _descriptor.Descriptor(
  name='GetNodeConfigResponse',
  full_name='rpcpb.GetNodeConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_pool_limit', full_name='rpcpb.GetNodeConfigResponse.tx_pool_limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blk_size_limit', full_name='rpcpb.GetNodeConfigResponse.blk_size_limit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_connection_out', full_name='rpcpb.GetNodeConfigResponse.max_connection_out', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_connection_in', full_name='rpcpb.GetNodeConfigResponse.max_connection_in', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producer_address', full_name='rpcpb.GetNodeConfigResponse.producer_address', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producers', full_name='rpcpb.GetNodeConfigResponse.producers', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_producers', full_name='rpcpb.GetNodeConfigResponse.max_producers', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipfs_addresses', full_name='rpcpb.GetNodeConfigResponse.ipfs_addresses', index=7,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rpc_port', full_name='rpcpb.GetNodeConfigResponse.rpc_port', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2402,
  serialized_end=2637,
)


_SETNODECONFIGREQUEST = _descriptor.Descriptor(
  name='SetNodeConfigRequest',
  full_name='rpcpb.SetNodeConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='updated_configs', full_name='rpcpb.SetNodeConfigRequest.updated_configs', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_pool_limit', full_name='rpcpb.SetNodeConfigRequest.tx_pool_limit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blk_size_limit', full_name='rpcpb.SetNodeConfigRequest.blk_size_limit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_connection_out', full_name='rpcpb.SetNodeConfigRequest.max_connection_out', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_connection_in', full_name='rpcpb.SetNodeConfigRequest.max_connection_in', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_producers', full_name='rpcpb.SetNodeConfigRequest.max_producers', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producers', full_name='rpcpb.SetNodeConfigRequest.producers', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SETNODECONFIGREQUEST_CONFIGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2640,
  serialized_end=2993,
)


_ESTIMATEGASRESPONSE = _descriptor.Descriptor(
  name='EstimateGasResponse',
  full_name='rpcpb.EstimateGasResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gas_count', full_name='rpcpb.EstimateGasResponse.gas_count', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2995,
  serialized_end=3035,
)


_GASPRICERESPONSE = _descriptor.Descriptor(
  name='GasPriceResponse',
  full_name='rpcpb.GasPriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gas_price', full_name='rpcpb.GasPriceResponse.gas_price', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3037,
  serialized_end=3074,
)


_CONTRACTQUERYRESPONSE = _descriptor.Descriptor(
  name='ContractQueryResponse',
  full_name='rpcpb.ContractQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rpcpb.ContractQueryResponse.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='rpcpb.ContractQueryResponse.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3127,
)

_SENDTRANSACTIONREQUEST.fields_by_name['transaction'].message_type = transaction__pb2._TRANSACTION
_SENDBATCHTRANSACTIONREQUEST.fields_by_name['transactions'].message_type = transaction__pb2._TRANSACTION
_ESTIMATEGASREQUEST.fields_by_name['transaction'].message_type = transaction__pb2._TRANSACTION
_GETPEERINFORESPONSE.fields_by_name['peer_list'].message_type = peer__pb2._PEERINFO
_GETUTXORESPONSE.fields_by_name['utxos'].message_type = utxo__pb2._UTXO
_GETUTXORESPONSE.fields_by_name['block_headers'].message_type = block__pb2._BLOCKHEADER
_GETBLOCKSRESPONSE.fields_by_name['blocks'].message_type = block__pb2._BLOCK
_GETBLOCKBYHASHRESPONSE.fields_by_name['block'].message_type = block__pb2._BLOCK
_GETBLOCKBYHEIGHTRESPONSE.fields_by_name['block'].message_type = block__pb2._BLOCK
_GETNEWTRANSACTIONRESPONSE.fields_by_name['transaction'].message_type = transaction__pb2._TRANSACTION
_GETALLTRANSACTIONSRESPONSE.fields_by_name['transactions'].message_type = transaction__pb2._TRANSACTION
_GETLASTIRREVERSIBLEBLOCKRESPONSE.fields_by_name['block'].message_type = block__pb2._BLOCK
_GETSTATSRESPONSE.fields_by_name['stats'].message_type = datastore__pb2._METRICS
_SETNODECONFIGREQUEST.fields_by_name['updated_configs'].enum_type = _SETNODECONFIGREQUEST_CONFIGTYPE
_SETNODECONFIGREQUEST_CONFIGTYPE.containing_type = _SETNODECONFIGREQUEST
DESCRIPTOR.message_types_by_name['CreateAccountRequest'] = _CREATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['UnlockAccountRequest'] = _UNLOCKACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['AddProducerRequest'] = _ADDPRODUCERREQUEST
DESCRIPTOR.message_types_by_name['GetBalanceRequest'] = _GETBALANCEREQUEST
DESCRIPTOR.message_types_by_name['SendFromMinerRequest'] = _SENDFROMMINERREQUEST
DESCRIPTOR.message_types_by_name['SendRequest'] = _SENDREQUEST
DESCRIPTOR.message_types_by_name['GetPeerInfoRequest'] = _GETPEERINFOREQUEST
DESCRIPTOR.message_types_by_name['GetBlockchainInfoRequest'] = _GETBLOCKCHAININFOREQUEST
DESCRIPTOR.message_types_by_name['AddPeerRequest'] = _ADDPEERREQUEST
DESCRIPTOR.message_types_by_name['GetVersionRequest'] = _GETVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetUTXORequest'] = _GETUTXOREQUEST
DESCRIPTOR.message_types_by_name['GetBlocksRequest'] = _GETBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['GetBlockByHashRequest'] = _GETBLOCKBYHASHREQUEST
DESCRIPTOR.message_types_by_name['GetBlockByHeightRequest'] = _GETBLOCKBYHEIGHTREQUEST
DESCRIPTOR.message_types_by_name['SendTransactionRequest'] = _SENDTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['SendBatchTransactionRequest'] = _SENDBATCHTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['GetNewTransactionRequest'] = _GETNEWTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRequest'] = _SUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['MetricsServiceRequest'] = _METRICSSERVICEREQUEST
DESCRIPTOR.message_types_by_name['GetLastIrreversibleBlockRequest'] = _GETLASTIRREVERSIBLEBLOCKREQUEST
DESCRIPTOR.message_types_by_name['EstimateGasRequest'] = _ESTIMATEGASREQUEST
DESCRIPTOR.message_types_by_name['GasPriceRequest'] = _GASPRICEREQUEST
DESCRIPTOR.message_types_by_name['ContractQueryRequest'] = _CONTRACTQUERYREQUEST
DESCRIPTOR.message_types_by_name['AddProducerResponse'] = _ADDPRODUCERRESPONSE
DESCRIPTOR.message_types_by_name['UnlockAccountResponse'] = _UNLOCKACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['GetBalanceResponse'] = _GETBALANCERESPONSE
DESCRIPTOR.message_types_by_name['SendFromMinerResponse'] = _SENDFROMMINERRESPONSE
DESCRIPTOR.message_types_by_name['SendResponse'] = _SENDRESPONSE
DESCRIPTOR.message_types_by_name['GetPeerInfoResponse'] = _GETPEERINFORESPONSE
DESCRIPTOR.message_types_by_name['GetBlockchainInfoResponse'] = _GETBLOCKCHAININFORESPONSE
DESCRIPTOR.message_types_by_name['AddPeerResponse'] = _ADDPEERRESPONSE
DESCRIPTOR.message_types_by_name['GetVersionResponse'] = _GETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['GetUTXOResponse'] = _GETUTXORESPONSE
DESCRIPTOR.message_types_by_name['GetBlocksResponse'] = _GETBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['GetBlockByHashResponse'] = _GETBLOCKBYHASHRESPONSE
DESCRIPTOR.message_types_by_name['GetBlockByHeightResponse'] = _GETBLOCKBYHEIGHTRESPONSE
DESCRIPTOR.message_types_by_name['SendTransactionResponse'] = _SENDTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['SendBatchTransactionResponse'] = _SENDBATCHTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['SendTransactionStatus'] = _SENDTRANSACTIONSTATUS
DESCRIPTOR.message_types_by_name['GetNewTransactionResponse'] = _GETNEWTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeResponse'] = _SUBSCRIBERESPONSE
DESCRIPTOR.message_types_by_name['GetAllTransactionsRequest'] = _GETALLTRANSACTIONSREQUEST
DESCRIPTOR.message_types_by_name['GetAllTransactionsResponse'] = _GETALLTRANSACTIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetLastIrreversibleBlockResponse'] = _GETLASTIRREVERSIBLEBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['GetStatsResponse'] = _GETSTATSRESPONSE
DESCRIPTOR.message_types_by_name['GetNodeConfigResponse'] = _GETNODECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetNodeConfigRequest'] = _SETNODECONFIGREQUEST
DESCRIPTOR.message_types_by_name['EstimateGasResponse'] = _ESTIMATEGASRESPONSE
DESCRIPTOR.message_types_by_name['GasPriceResponse'] = _GASPRICERESPONSE
DESCRIPTOR.message_types_by_name['ContractQueryResponse'] = _CONTRACTQUERYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

UnlockAccountRequest = _reflection.GeneratedProtocolMessageType('UnlockAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKACCOUNTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.UnlockAccountRequest)
  })
_sym_db.RegisterMessage(UnlockAccountRequest)

AddProducerRequest = _reflection.GeneratedProtocolMessageType('AddProducerRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPRODUCERREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.AddProducerRequest)
  })
_sym_db.RegisterMessage(AddProducerRequest)

GetBalanceRequest = _reflection.GeneratedProtocolMessageType('GetBalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBalanceRequest)
  })
_sym_db.RegisterMessage(GetBalanceRequest)

SendFromMinerRequest = _reflection.GeneratedProtocolMessageType('SendFromMinerRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDFROMMINERREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendFromMinerRequest)
  })
_sym_db.RegisterMessage(SendFromMinerRequest)

SendRequest = _reflection.GeneratedProtocolMessageType('SendRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendRequest)
  })
_sym_db.RegisterMessage(SendRequest)

GetPeerInfoRequest = _reflection.GeneratedProtocolMessageType('GetPeerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPEERINFOREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetPeerInfoRequest)
  })
_sym_db.RegisterMessage(GetPeerInfoRequest)

GetBlockchainInfoRequest = _reflection.GeneratedProtocolMessageType('GetBlockchainInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKCHAININFOREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlockchainInfoRequest)
  })
_sym_db.RegisterMessage(GetBlockchainInfoRequest)

AddPeerRequest = _reflection.GeneratedProtocolMessageType('AddPeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPEERREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.AddPeerRequest)
  })
_sym_db.RegisterMessage(AddPeerRequest)

GetVersionRequest = _reflection.GeneratedProtocolMessageType('GetVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetVersionRequest)
  })
_sym_db.RegisterMessage(GetVersionRequest)

GetUTXORequest = _reflection.GeneratedProtocolMessageType('GetUTXORequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUTXOREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetUTXORequest)
  })
_sym_db.RegisterMessage(GetUTXORequest)

GetBlocksRequest = _reflection.GeneratedProtocolMessageType('GetBlocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlocksRequest)
  })
_sym_db.RegisterMessage(GetBlocksRequest)

GetBlockByHashRequest = _reflection.GeneratedProtocolMessageType('GetBlockByHashRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHASHREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlockByHashRequest)
  })
_sym_db.RegisterMessage(GetBlockByHashRequest)

GetBlockByHeightRequest = _reflection.GeneratedProtocolMessageType('GetBlockByHeightRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHEIGHTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlockByHeightRequest)
  })
_sym_db.RegisterMessage(GetBlockByHeightRequest)

SendTransactionRequest = _reflection.GeneratedProtocolMessageType('SendTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDTRANSACTIONREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendTransactionRequest)
  })
_sym_db.RegisterMessage(SendTransactionRequest)

SendBatchTransactionRequest = _reflection.GeneratedProtocolMessageType('SendBatchTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDBATCHTRANSACTIONREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendBatchTransactionRequest)
  })
_sym_db.RegisterMessage(SendBatchTransactionRequest)

GetNewTransactionRequest = _reflection.GeneratedProtocolMessageType('GetNewTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWTRANSACTIONREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetNewTransactionRequest)
  })
_sym_db.RegisterMessage(GetNewTransactionRequest)

SubscribeRequest = _reflection.GeneratedProtocolMessageType('SubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SubscribeRequest)
  })
_sym_db.RegisterMessage(SubscribeRequest)

MetricsServiceRequest = _reflection.GeneratedProtocolMessageType('MetricsServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICSSERVICEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.MetricsServiceRequest)
  })
_sym_db.RegisterMessage(MetricsServiceRequest)

GetLastIrreversibleBlockRequest = _reflection.GeneratedProtocolMessageType('GetLastIrreversibleBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLASTIRREVERSIBLEBLOCKREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetLastIrreversibleBlockRequest)
  })
_sym_db.RegisterMessage(GetLastIrreversibleBlockRequest)

EstimateGasRequest = _reflection.GeneratedProtocolMessageType('EstimateGasRequest', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATEGASREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.EstimateGasRequest)
  })
_sym_db.RegisterMessage(EstimateGasRequest)

GasPriceRequest = _reflection.GeneratedProtocolMessageType('GasPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GASPRICEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GasPriceRequest)
  })
_sym_db.RegisterMessage(GasPriceRequest)

ContractQueryRequest = _reflection.GeneratedProtocolMessageType('ContractQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTQUERYREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.ContractQueryRequest)
  })
_sym_db.RegisterMessage(ContractQueryRequest)

AddProducerResponse = _reflection.GeneratedProtocolMessageType('AddProducerResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDPRODUCERRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.AddProducerResponse)
  })
_sym_db.RegisterMessage(AddProducerResponse)

UnlockAccountResponse = _reflection.GeneratedProtocolMessageType('UnlockAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNLOCKACCOUNTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.UnlockAccountResponse)
  })
_sym_db.RegisterMessage(UnlockAccountResponse)

GetBalanceResponse = _reflection.GeneratedProtocolMessageType('GetBalanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBalanceResponse)
  })
_sym_db.RegisterMessage(GetBalanceResponse)

SendFromMinerResponse = _reflection.GeneratedProtocolMessageType('SendFromMinerResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDFROMMINERRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendFromMinerResponse)
  })
_sym_db.RegisterMessage(SendFromMinerResponse)

SendResponse = _reflection.GeneratedProtocolMessageType('SendResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendResponse)
  })
_sym_db.RegisterMessage(SendResponse)

GetPeerInfoResponse = _reflection.GeneratedProtocolMessageType('GetPeerInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPEERINFORESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetPeerInfoResponse)
  })
_sym_db.RegisterMessage(GetPeerInfoResponse)

GetBlockchainInfoResponse = _reflection.GeneratedProtocolMessageType('GetBlockchainInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKCHAININFORESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlockchainInfoResponse)
  })
_sym_db.RegisterMessage(GetBlockchainInfoResponse)

AddPeerResponse = _reflection.GeneratedProtocolMessageType('AddPeerResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDPEERRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.AddPeerResponse)
  })
_sym_db.RegisterMessage(AddPeerResponse)

GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetVersionResponse)
  })
_sym_db.RegisterMessage(GetVersionResponse)

GetUTXOResponse = _reflection.GeneratedProtocolMessageType('GetUTXOResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUTXORESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetUTXOResponse)
  })
_sym_db.RegisterMessage(GetUTXOResponse)

GetBlocksResponse = _reflection.GeneratedProtocolMessageType('GetBlocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlocksResponse)
  })
_sym_db.RegisterMessage(GetBlocksResponse)

GetBlockByHashResponse = _reflection.GeneratedProtocolMessageType('GetBlockByHashResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHASHRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlockByHashResponse)
  })
_sym_db.RegisterMessage(GetBlockByHashResponse)

GetBlockByHeightResponse = _reflection.GeneratedProtocolMessageType('GetBlockByHeightResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHEIGHTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetBlockByHeightResponse)
  })
_sym_db.RegisterMessage(GetBlockByHeightResponse)

SendTransactionResponse = _reflection.GeneratedProtocolMessageType('SendTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDTRANSACTIONRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendTransactionResponse)
  })
_sym_db.RegisterMessage(SendTransactionResponse)

SendBatchTransactionResponse = _reflection.GeneratedProtocolMessageType('SendBatchTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDBATCHTRANSACTIONRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendBatchTransactionResponse)
  })
_sym_db.RegisterMessage(SendBatchTransactionResponse)

SendTransactionStatus = _reflection.GeneratedProtocolMessageType('SendTransactionStatus', (_message.Message,), {
  'DESCRIPTOR' : _SENDTRANSACTIONSTATUS,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SendTransactionStatus)
  })
_sym_db.RegisterMessage(SendTransactionStatus)

GetNewTransactionResponse = _reflection.GeneratedProtocolMessageType('GetNewTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWTRANSACTIONRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetNewTransactionResponse)
  })
_sym_db.RegisterMessage(GetNewTransactionResponse)

SubscribeResponse = _reflection.GeneratedProtocolMessageType('SubscribeResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SubscribeResponse)
  })
_sym_db.RegisterMessage(SubscribeResponse)

GetAllTransactionsRequest = _reflection.GeneratedProtocolMessageType('GetAllTransactionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLTRANSACTIONSREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetAllTransactionsRequest)
  })
_sym_db.RegisterMessage(GetAllTransactionsRequest)

GetAllTransactionsResponse = _reflection.GeneratedProtocolMessageType('GetAllTransactionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLTRANSACTIONSRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetAllTransactionsResponse)
  })
_sym_db.RegisterMessage(GetAllTransactionsResponse)

GetLastIrreversibleBlockResponse = _reflection.GeneratedProtocolMessageType('GetLastIrreversibleBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLASTIRREVERSIBLEBLOCKRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetLastIrreversibleBlockResponse)
  })
_sym_db.RegisterMessage(GetLastIrreversibleBlockResponse)

GetStatsResponse = _reflection.GeneratedProtocolMessageType('GetStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATSRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetStatsResponse)
  })
_sym_db.RegisterMessage(GetStatsResponse)

GetNodeConfigResponse = _reflection.GeneratedProtocolMessageType('GetNodeConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODECONFIGRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GetNodeConfigResponse)
  })
_sym_db.RegisterMessage(GetNodeConfigResponse)

SetNodeConfigRequest = _reflection.GeneratedProtocolMessageType('SetNodeConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETNODECONFIGREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.SetNodeConfigRequest)
  })
_sym_db.RegisterMessage(SetNodeConfigRequest)

EstimateGasResponse = _reflection.GeneratedProtocolMessageType('EstimateGasResponse', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATEGASRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.EstimateGasResponse)
  })
_sym_db.RegisterMessage(EstimateGasResponse)

GasPriceResponse = _reflection.GeneratedProtocolMessageType('GasPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GASPRICERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.GasPriceResponse)
  })
_sym_db.RegisterMessage(GasPriceResponse)

ContractQueryResponse = _reflection.GeneratedProtocolMessageType('ContractQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTQUERYRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpcpb.ContractQueryResponse)
  })
_sym_db.RegisterMessage(ContractQueryResponse)



_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RpcService',
  full_name='rpcpb.RpcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3130,
  serialized_end=4482,
  methods=[
  _descriptor.MethodDescriptor(
    name='RpcGetVersion',
    full_name='rpcpb.RpcService.RpcGetVersion',
    index=0,
    containing_service=None,
    input_type=_GETVERSIONREQUEST,
    output_type=_GETVERSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetBalance',
    full_name='rpcpb.RpcService.RpcGetBalance',
    index=1,
    containing_service=None,
    input_type=_GETBALANCEREQUEST,
    output_type=_GETBALANCERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetBlockchainInfo',
    full_name='rpcpb.RpcService.RpcGetBlockchainInfo',
    index=2,
    containing_service=None,
    input_type=_GETBLOCKCHAININFOREQUEST,
    output_type=_GETBLOCKCHAININFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetUTXO',
    full_name='rpcpb.RpcService.RpcGetUTXO',
    index=3,
    containing_service=None,
    input_type=_GETUTXOREQUEST,
    output_type=_GETUTXORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetBlocks',
    full_name='rpcpb.RpcService.RpcGetBlocks',
    index=4,
    containing_service=None,
    input_type=_GETBLOCKSREQUEST,
    output_type=_GETBLOCKSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetBlockByHash',
    full_name='rpcpb.RpcService.RpcGetBlockByHash',
    index=5,
    containing_service=None,
    input_type=_GETBLOCKBYHASHREQUEST,
    output_type=_GETBLOCKBYHASHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetBlockByHeight',
    full_name='rpcpb.RpcService.RpcGetBlockByHeight',
    index=6,
    containing_service=None,
    input_type=_GETBLOCKBYHEIGHTREQUEST,
    output_type=_GETBLOCKBYHEIGHTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcSendTransaction',
    full_name='rpcpb.RpcService.RpcSendTransaction',
    index=7,
    containing_service=None,
    input_type=_SENDTRANSACTIONREQUEST,
    output_type=_SENDTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcSendBatchTransaction',
    full_name='rpcpb.RpcService.RpcSendBatchTransaction',
    index=8,
    containing_service=None,
    input_type=_SENDBATCHTRANSACTIONREQUEST,
    output_type=_SENDBATCHTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetNewTransaction',
    full_name='rpcpb.RpcService.RpcGetNewTransaction',
    index=9,
    containing_service=None,
    input_type=_GETNEWTRANSACTIONREQUEST,
    output_type=_GETNEWTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcSubscribe',
    full_name='rpcpb.RpcService.RpcSubscribe',
    index=10,
    containing_service=None,
    input_type=_SUBSCRIBEREQUEST,
    output_type=_SUBSCRIBERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetAllTransactionsFromTxPool',
    full_name='rpcpb.RpcService.RpcGetAllTransactionsFromTxPool',
    index=11,
    containing_service=None,
    input_type=_GETALLTRANSACTIONSREQUEST,
    output_type=_GETALLTRANSACTIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetLastIrreversibleBlock',
    full_name='rpcpb.RpcService.RpcGetLastIrreversibleBlock',
    index=12,
    containing_service=None,
    input_type=_GETLASTIRREVERSIBLEBLOCKREQUEST,
    output_type=_GETLASTIRREVERSIBLEBLOCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcEstimateGas',
    full_name='rpcpb.RpcService.RpcEstimateGas',
    index=13,
    containing_service=None,
    input_type=_ESTIMATEGASREQUEST,
    output_type=_ESTIMATEGASRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGasPrice',
    full_name='rpcpb.RpcService.RpcGasPrice',
    index=14,
    containing_service=None,
    input_type=_GASPRICEREQUEST,
    output_type=_GASPRICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcContractQuery',
    full_name='rpcpb.RpcService.RpcContractQuery',
    index=15,
    containing_service=None,
    input_type=_CONTRACTQUERYREQUEST,
    output_type=_CONTRACTQUERYRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RpcService'] = _RPCSERVICE


_ADMINSERVICE = _descriptor.ServiceDescriptor(
  name='AdminService',
  full_name='rpcpb.AdminService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=4485,
  serialized_end=4928,
  methods=[
  _descriptor.MethodDescriptor(
    name='RpcAddPeer',
    full_name='rpcpb.AdminService.RpcAddPeer',
    index=0,
    containing_service=None,
    input_type=_ADDPEERREQUEST,
    output_type=_ADDPEERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcSend',
    full_name='rpcpb.AdminService.RpcSend',
    index=1,
    containing_service=None,
    input_type=_SENDREQUEST,
    output_type=_SENDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetPeerInfo',
    full_name='rpcpb.AdminService.RpcGetPeerInfo',
    index=2,
    containing_service=None,
    input_type=_GETPEERINFOREQUEST,
    output_type=_GETPEERINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcSendFromMiner',
    full_name='rpcpb.AdminService.RpcSendFromMiner',
    index=3,
    containing_service=None,
    input_type=_SENDFROMMINERREQUEST,
    output_type=_SENDFROMMINERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcAddProducer',
    full_name='rpcpb.AdminService.RpcAddProducer',
    index=4,
    containing_service=None,
    input_type=_ADDPRODUCERREQUEST,
    output_type=_ADDPRODUCERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcUnlockAccount',
    full_name='rpcpb.AdminService.RpcUnlockAccount',
    index=5,
    containing_service=None,
    input_type=_UNLOCKACCOUNTREQUEST,
    output_type=_UNLOCKACCOUNTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMINSERVICE)

DESCRIPTOR.services_by_name['AdminService'] = _ADMINSERVICE


_METRICSERVICE = _descriptor.ServiceDescriptor(
  name='MetricService',
  full_name='rpcpb.MetricService',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  serialized_start=4931,
  serialized_end=5181,
  methods=[
  _descriptor.MethodDescriptor(
    name='RpcGetStats',
    full_name='rpcpb.MetricService.RpcGetStats',
    index=0,
    containing_service=None,
    input_type=_METRICSSERVICEREQUEST,
    output_type=_GETSTATSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcGetNodeConfig',
    full_name='rpcpb.MetricService.RpcGetNodeConfig',
    index=1,
    containing_service=None,
    input_type=_METRICSSERVICEREQUEST,
    output_type=_GETNODECONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RpcSetNodeConfig',
    full_name='rpcpb.MetricService.RpcSetNodeConfig',
    index=2,
    containing_service=None,
    input_type=_SETNODECONFIGREQUEST,
    output_type=_GETNODECONFIGRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_METRICSERVICE)

DESCRIPTOR.services_by_name['MetricService'] = _METRICSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: utxo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='utxo.proto',
  package='utxopb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\nutxo.proto\x12\x06utxopb\"s\n\x04Utxo\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x0c\x12\x17\n\x0fpublic_key_hash\x18\x02 \x01(\x0c\x12\x0c\n\x04txid\x18\x03 \x01(\x0c\x12\x10\n\x08tx_index\x18\x04 \x01(\r\x12\x10\n\x08utxoType\x18\x05 \x01(\r\x12\x10\n\x08\x63ontract\x18\x06 \x01(\t\"\'\n\x08UtxoList\x12\x1b\n\x05utxos\x18\x01 \x03(\x0b\x32\x0c.utxopb.Utxob\x06proto3'
)




_UTXO = _descriptor.Descriptor(
  name='Utxo',
  full_name='utxopb.Utxo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='utxopb.Utxo.amount', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key_hash', full_name='utxopb.Utxo.public_key_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txid', full_name='utxopb.Utxo.txid', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_index', full_name='utxopb.Utxo.tx_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='utxoType', full_name='utxopb.Utxo.utxoType', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contract', full_name='utxopb.Utxo.contract', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=137,
)


_UTXOLIST = _descriptor.Descriptor(
  name='UtxoList',
  full_name='utxopb.UtxoList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='utxos', full_name='utxopb.UtxoList.utxos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=178,
)

_UTXOLIST.fields_by_name['utxos'].message_type = _UTXO
DESCRIPTOR.message_types_by_name['Utxo'] = _UTXO
DESCRIPTOR.message_types_by_name['UtxoList'] = _UTXOLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Utxo = _reflection.GeneratedProtocolMessageType('Utxo', (_message.Message,), {
  'DESCRIPTOR' : _UTXO,
  '__module__' : 'utxo_pb2'
  # @@protoc_insertion_point(class_scope:utxopb.Utxo)
  })
_sym_db.RegisterMessage(Utxo)

UtxoList = _reflection.GeneratedProtocolMessageType('UtxoList', (_message.Message,), {
  'DESCRIPTOR' : _UTXOLIST,
  '__module__' : 'utxo_pb2'
  # @@protoc_insertion_point(class_scope:utxopb.UtxoList)
  })
_sym_db.RegisterMessage(UtxoList)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datastore.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import peer_pb2 as peer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='datastore.proto',
  package='metricspb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x0f\x64\x61tastore.proto\x12\tmetricspb\x1a\npeer.proto\"\xe7\x01\n\x04Stat\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x1f\n\x15transaction_pool_size\x18\x02 \x01(\x03H\x00\x12.\n\x0cmemory_stats\x18\x03 \x01(\x0b\x32\x16.metricspb.MemoryStatsH\x00\x12\x18\n\x0e\x63pu_percentage\x18\x04 \x01(\x01H\x00\x12*\n\nfork_stats\x18\x05 \x01(\x0b\x32\x14.metricspb.ForkStatsH\x00\x12,\n\x0b\x62lock_stats\x18\x06 \x01(\x0b\x32\x15.metricspb.BlockStatsH\x00\x42\x07\n\x05value\"4\n\x0bMemoryStats\x12\x13\n\x0bheap_in_use\x18\x01 \x01(\x04\x12\x10\n\x08heap_sys\x18\x02 \x01(\x04\"4\n\tForkStats\x12\x11\n\tnum_forks\x18\x01 \x01(\x03\x12\x14\n\x0clongest_fork\x18\x02 \x01(\x03\"6\n\nBlockStats\x12\x18\n\x10num_transactions\x18\x01 \x01(\x04\x12\x0e\n\x06height\x18\x02 \x01(\x04\"(\n\x06Metric\x12\x1e\n\x05stats\x18\x01 \x03(\x0b\x32\x0f.metricspb.Stat\"\x82\x01\n\tDataStore\x12\x32\n\x07metrics\x18\x01 \x03(\x0b\x32!.metricspb.DataStore.MetricsEntry\x1a\x41\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.metricspb.Metric:\x02\x38\x01\"\x83\x01\n\x07Metrics\x12(\n\ndata_store\x18\x01 \x01(\x0b\x32\x14.metricspb.DataStore\x12\"\n\x05peers\x18\x02 \x03(\x0b\x32\x13.networkpb.PeerInfo\x12*\n\x0b\x62lock_stats\x18\x03 \x03(\x0b\x32\x15.metricspb.BlockStatsb\x06proto3'
  ,
  dependencies=[peer__pb2.DESCRIPTOR,])




_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='metricspb.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='metricspb.Stat.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_pool_size', full_name='metricspb.Stat.transaction_pool_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory_stats', full_name='metricspb.Stat.memory_stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_percentage', full_name='metricspb.Stat.cpu_percentage', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fork_stats', full_name='metricspb.Stat.fork_stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_stats', full_name='metricspb.Stat.block_stats', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='metricspb.Stat.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=43,
  serialized_end=274,
)


_MEMORYSTATS = _descriptor.Descriptor(
  name='MemoryStats',
  full_name='metricspb.MemoryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heap_in_use', full_name='metricspb.MemoryStats.heap_in_use', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_sys', full_name='metricspb.MemoryStats.heap_sys', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=328,
)


_FORKSTATS = _descriptor.Descriptor(
  name='ForkStats',
  full_name='metricspb.ForkStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_forks', full_name='metricspb.ForkStats.num_forks', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longest_fork', full_name='metricspb.ForkStats.longest_fork', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=382,
)


_BLOCKSTATS = _descriptor.Descriptor(
  name='BlockStats',
  full_name='metricspb.BlockStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_transactions', full_name='metricspb.BlockStats.num_transactions', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='metricspb.BlockStats.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=438,
)


_METRIC = _descriptor.Descriptor(
  name='Metric',
  full_name='metricspb.Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='metricspb.Metric.stats', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=480,
)


_DATASTORE_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='metricspb.DataStore.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='metricspb.DataStore.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='metricspb.DataStore.MetricsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=613,
)

_DATASTORE = _descriptor.Descriptor(
  name='DataStore',
  full_name='metricspb.DataStore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='metricspb.DataStore.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASTORE_METRICSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=613,
)


_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='metricspb.Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_store', full_name='metricspb.Metrics.data_store', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peers', full_name='metricspb.Metrics.peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_stats', full_name='metricspb.Metrics.block_stats', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=747,
)

_STAT.fields_by_name['memory_stats'].message_type = _MEMORYSTATS
_STAT.fields_by_name['fork_stats'].message_type = _FORKSTATS
_STAT.fields_by_name['block_stats'].message_type = _BLOCKSTATS
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['transaction_pool_size'])
_STAT.fields_by_name['transaction_pool_size'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['memory_stats'])
_STAT.fields_by_name['memory_stats'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['cpu_percentage'])
_STAT.fields_by_name['cpu_percentage'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['fork_stats'])
_STAT.fields_by_name['fork_stats'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['block_stats'])
_STAT.fields_by_name['block_stats'].containing_oneof = _STAT.oneofs_by_name['value']
_METRIC.fields_by_name['stats'].message_type = _STAT
_DATASTORE_METRICSENTRY.fields_by_name['value'].message_type = _METRIC
_DATASTORE_METRICSENTRY.containing_type = _DATASTORE
_DATASTORE.fields_by_name['metrics'].message_type = _DATASTORE_METRICSENTRY
_METRICS.fields_by_name['data_store'].message_type = _DATASTORE
_METRICS.fields_by_name['peers'].message_type = peer__pb2._PEERINFO
_METRICS.fields_by_name['block_stats'].message_type = _BLOCKSTATS
DESCRIPTOR.message_types_by_name['Stat'] = _STAT
DESCRIPTOR.message_types_by_name['MemoryStats'] = _MEMORYSTATS
DESCRIPTOR.message_types_by_name['ForkStats'] = _FORKSTATS
DESCRIPTOR.message_types_by_name['BlockStats'] = _BLOCKSTATS
DESCRIPTOR.message_types_by_name['Metric'] = _METRIC
DESCRIPTOR.message_types_by_name['DataStore'] = _DATASTORE
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), {
  'DESCRIPTOR' : _STAT,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.Stat)
  })
_sym_db.RegisterMessage(Stat)

MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYSTATS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.MemoryStats)
  })
_sym_db.RegisterMessage(MemoryStats)

ForkStats = _reflection.GeneratedProtocolMessageType('ForkStats', (_message.Message,), {
  'DESCRIPTOR' : _FORKSTATS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.ForkStats)
  })
_sym_db.RegisterMessage(ForkStats)

BlockStats = _reflection.GeneratedProtocolMessageType('BlockStats', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKSTATS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.BlockStats)
  })
_sym_db.RegisterMessage(BlockStats)

Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.Metric)
  })
_sym_db.RegisterMessage(Metric)

DataStore = _reflection.GeneratedProtocolMessageType('DataStore', (_message.Message,), {

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASTORE_METRICSENTRY,
    '__module__' : 'datastore_pb2'
    # @@protoc_insertion_point(class_scope:metricspb.DataStore.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASTORE,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.DataStore)
  })
_sym_db.RegisterMessage(DataStore)
_sym_db.RegisterMessage(DataStore.MetricsEntry)

Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {
  'DESCRIPTOR' : _METRICS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.Metrics)
  })
_sym_db.RegisterMessage(Metrics)


_DATASTORE_METRICSENTRY._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: enjoyass
# Mail: enjoyass@outlook.com
# Created Time:  2020-7-21 10:17:34
#############################################


from setuptools import setup, find_packages

setup(
    name = "dappleyPython",
    version = "0.0.1",
    keywords = ("pip", "sdk","dappley","dappworks","dappleyPython"),
    description = "dappley sdk is implemented by python",
    long_description = "dappley sdk is implemented by python ,you can send transaction to dappley blockchain by this sdk",
    license = "LGPL v3 Licence",

    url = "https://github.com/dappley/dappley-sdk-python",
    author = "enjoyass",
    author_email = "enjoyass@outlook.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = [
        'grpcio==1.28.1',
        'google==2.0.3',
        'protobuf==3.11.3',
        'base58==1.0.3',
        'grpc~=0.3.post19',
        'secp256k1~=0.13.2',
        'pysha3==1.0.2'
    ]
)


import math

ADDRESS_CHECKSUM_LENGTH = 4
CHARSET_UTF_8 = "UTF-8"
COIN_SCALE = 9
COIN_DW = math.pow(10, 9)

TxTypeDefault = 0
TxTypeNormal = 1
TxTypeContract = 2
TxTypeCoinbase = 3
TxTypeGasReward = 4
TxTypeGasChange = 5
TxTypeReward = 6
